@@ -21,16 +21,6 @@ from datetime import datetime
 # from numba import jit,typed
 # from qt_material import apply_stylesheet
 from diskcache import Cache
-
-
-
-
-
-
-
-
-
-import binascii
 import crcmod.predefined
 
 
@@ -1085,8 +1075,18 @@ class Serial_boot(QMainWindow, Ui_boot_MainWindow):
 
 
 
+def main_run():
+    app = 0
+    app = QApplication(sys.argv)
+
+    myshow = Serial_boot()
+    myshow.show()
+    # apply_stylesheet(app, theme='dark_teal.xml')
+
+    sys.exit(app.exec())
 
 if __name__ == '__main__':
+
     app = 0
     app = QApplication(sys.argv)
 
